==> haskell-xml-types-0.3.8-9-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-xml-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xml-types
version:              0.3.8
visibility:           public
id:                   xml-types-0.3.8-LZyzf9bLT8K9kdiyyQ9IUF
key:                  xml-types-0.3.8-LZyzf9bLT8K9kdiyyQ9IUF
license:              MIT
maintainer:           Stephen Paul Weber <singpolyma@singpolyma.net>
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://git.singpolyma.net/xml-types-haskell
synopsis:             Basic types for representing XML
description:
    Basic types for representing XML.

    The idea is to have a full set of appropriate types, which various XML
    libraries can share. Instead of having equivalent-but-incompatible types
    for every binding, parser, or client, they all share the same types can
    can thus interoperate easily.

    This library contains complete types for most parts of an XML document,
    including the prologue, node tree, and doctype. Some basic combinators
    are included for common tasks, including traversing the node tree and
    filtering children.

category:             Text, XML
abi:                  6d3a5247ffcc6614ed42bd82f4c77c62
exposed:              True
exposed-modules:      Data.XML.Types
import-dirs:          /usr/lib/ghc-9.2.8/site-local/xml-types-0.3.8
library-dirs:         /usr/lib/ghc-9.2.8/site-local/xml-types-0.3.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xml-types
hs-libraries:         HSxml-types-0.3.8-LZyzf9bLT8K9kdiyyQ9IUF
depends:              base-4.16.4.0 deepseq-1.4.6.1 text-1.2.5.0
haddock-interfaces:   /usr/share/doc/haskell-xml-types/html/xml-types.haddock
haddock-html:         /usr/share/doc/haskell-xml-types/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-types-0.3.8-10-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-xml-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xml-types
version:              0.3.8
visibility:           public
id:                   xml-types-0.3.8-IpGyuvvNOu2AH1SOobl25
key:                  xml-types-0.3.8-IpGyuvvNOu2AH1SOobl25
license:              MIT
maintainer:           Stephen Paul Weber <singpolyma@singpolyma.net>
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://git.singpolyma.net/xml-types-haskell
synopsis:             Basic types for representing XML
description:
    Basic types for representing XML.

    The idea is to have a full set of appropriate types, which various XML
    libraries can share. Instead of having equivalent-but-incompatible types
    for every binding, parser, or client, they all share the same types can
    can thus interoperate easily.

    This library contains complete types for most parts of an XML document,
    including the prologue, node tree, and doctype. Some basic combinators
    are included for common tasks, including traversing the node tree and
    filtering children.

category:             Text, XML
abi:                  6a3f0a1523bcf899f9ceb02daecc66c7
exposed:              True
exposed-modules:      Data.XML.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/xml-types-0.3.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xml-types-0.3.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xml-types-0.3.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xml-types
hs-libraries:         HSxml-types-0.3.8-IpGyuvvNOu2AH1SOobl25
depends:              base-4.17.2.1 deepseq-1.4.8.0 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-xml-types/html/xml-types.haddock
haddock-html:         /usr/share/doc/haskell-xml-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
